aboutsummaryrefslogtreecommitdiffstats
path: root/examples/opengl/hellogl2.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/opengl/hellogl2.py')
-rw-r--r--examples/opengl/hellogl2.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/examples/opengl/hellogl2.py b/examples/opengl/hellogl2.py
index fd5d79be3..bcffdf3c9 100644
--- a/examples/opengl/hellogl2.py
+++ b/examples/opengl/hellogl2.py
@@ -40,20 +40,20 @@
##
############################################################################
"""PySide2 port of the opengl/hellogl2 example from Qt v5.x"""
import sys
import math
import numpy
import ctypes
-from PySide2.QtCore import QCoreApplication, Signal, SIGNAL, SLOT, Qt, QSize, QPoint
-from PySide2.QtGui import (QVector3D, QOpenGLFunctions,
+from PySide6.QtCore import QCoreApplication, Signal, SIGNAL, SLOT, Qt, QSize, QPoint
+from PySide6.QtGui import (QVector3D, QOpenGLFunctions,
QMatrix4x4, QOpenGLContext, QSurfaceFormat)
-from PySide2.QtOpenGL import (QOpenGLVertexArrayObject, QOpenGLBuffer,
+from PySide6.QtOpenGL import (QOpenGLVertexArrayObject, QOpenGLBuffer,
QOpenGLShaderProgram, QOpenGLShader)
-from PySide2.QtWidgets import (QApplication, QWidget, QMessageBox, QHBoxLayout,
+from PySide6.QtWidgets import (QApplication, QWidget, QMessageBox, QHBoxLayout,
QSlider)
-from PySide2.QtOpenGLWidgets import QOpenGLWidget
+from PySide6.QtOpenGLWidgets import QOpenGLWidget
from shiboken6 import VoidPtr
@@ -40,20 +40,20 @@
##
############################################################################
-"""PySide2 port of the opengl/hellogl2 example from Qt v5.x"""
+"""PySide6 port of the opengl/hellogl2 example from Qt v5.x"""
import sys
import math